pub enum ActivityReporterRequest {
WatchRenderActivity {
responder: ActivityReporterWatchRenderActivityResponder,
},
WatchRenderActivity2 {
responder: ActivityReporterWatchRenderActivity2Responder,
},
WatchCaptureActivity {
responder: ActivityReporterWatchCaptureActivityResponder,
},
WatchCaptureActivity2 {
responder: ActivityReporterWatchCaptureActivity2Responder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ActivityReporterControlHandle,
method_type: MethodType,
},
}Expand description
A protocol for monitoring the usage activity of the AudioRenderers and AudioCapturers.
Variants
WatchRenderActivity
Notifies the client whenever there is a change in the set of active AudioRenderUsages. It returns immediately the first time that it is called.
Fields
WatchRenderActivity2
Notifies the client whenever there is a change in the set of active AudioRenderUsages. It returns immediately the first time that it is called.
Fields
WatchCaptureActivity
Notifies the client whenever there is a change in the set of active AudioCaptureUsages. It returns immediately the first time that it is called.
Fields
WatchCaptureActivity2
Notifies the client whenever there is a change in the set of active AudioCaptureUsages. It returns immediately the first time that it is called.
Fields
#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
control_handle: ActivityReporterControlHandlemethod_type: MethodTypeImplementations
Sourceimpl ActivityReporterRequest
impl ActivityReporterRequest
pub fn into_watch_render_activity( self, ) -> Option<ActivityReporterWatchRenderActivityResponder>
pub fn into_watch_render_activity2( self, ) -> Option<ActivityReporterWatchRenderActivity2Responder>
pub fn into_watch_capture_activity( self, ) -> Option<ActivityReporterWatchCaptureActivityResponder>
pub fn into_watch_capture_activity2( self, ) -> Option<ActivityReporterWatchCaptureActivity2Responder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL