pub struct StreamSourceProxy { /* private fields */ }Implementations
Sourceimpl StreamSourceProxy
impl StreamSourceProxy
Sourcepub fn take_event_stream(&self) -> StreamSourceEventStream
pub fn take_event_stream(&self) -> StreamSourceEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn release_packet(&self, packet: &StreamPacket) -> Result<(), Error>
pub fn release_packet(&self, packet: &StreamPacket) -> Result<(), Error>
Releases payload memory associated with a packet previously delivered
via OnPacketProduced.
pub fn discard_all_packets( &self, ) -> QueryResponseFut<(), FDomainResourceDialect>
pub fn discard_all_packets_no_reply(&self) -> Result<(), Error>