pub struct UsageGainListenerProxy { /* private fields */ }Implementations
Sourceimpl UsageGainListenerProxy
impl UsageGainListenerProxy
Sourcepub fn take_event_stream(&self) -> UsageGainListenerEventStream
pub fn take_event_stream(&self) -> UsageGainListenerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn on_gain_mute_changed(
&self,
muted: bool,
gain_dbfs: f32,
) -> QueryResponseFut<(), FDomainResourceDialect>
pub fn on_gain_mute_changed( &self, muted: bool, gain_dbfs: f32, ) -> QueryResponseFut<(), FDomainResourceDialect>
Called immediately on connection and afterward any time the usage gain setting changes.
Clients must respond to acknowledge the event. Clients that do not acknowledge their events will eventually be disconnected.
Note: This API does not have mute reporting implemented; muted is always false.