pub struct UsageGainReporterProxy { /* private fields */ }Implementations
Sourceimpl UsageGainReporterProxy
impl UsageGainReporterProxy
Sourcepub fn take_event_stream(&self) -> UsageGainReporterEventStream
pub fn take_event_stream(&self) -> UsageGainReporterEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn register_listener(
&self,
device_unique_id: &str,
usage: &Usage,
usage_gain_listener: ClientEnd<UsageGainListenerMarker>,
) -> Result<(), Error>
pub fn register_listener( &self, device_unique_id: &str, usage: &Usage, usage_gain_listener: ClientEnd<UsageGainListenerMarker>, ) -> Result<(), Error>
Connects a listener to a stream of usage gain setting changes
for usage on the device identified by device_token. Usage
Gain is not set directly by any client; it is a translation of
the usage volume setting for each device, summed with active
muting/ducking gain adjustments.
Devices may map the same volume level to different dbfs, so
a device_unique_id is needed to identify the device.
AudioDeviceEnumerator provides programmatic access to devices
and their unique ids if it is necessary for a client to select
an id at runtime.
Sourcepub fn register_listener2(
&self,
device_unique_id: &str,
usage: &Usage2,
usage_gain_listener: ClientEnd<UsageGainListenerMarker>,
) -> Result<(), Error>
pub fn register_listener2( &self, device_unique_id: &str, usage: &Usage2, usage_gain_listener: ClientEnd<UsageGainListenerMarker>, ) -> Result<(), Error>
Connects a listener to a stream of usage gain setting changes
for usage on the device identified by device_token. Usage
Gain is not set directly by any client; it is a translation of
the usage volume setting for each device, summed with active
muting/ducking gain adjustments.
Devices may map the same volume level to different dbfs, so
a device_unique_id is needed to identify the device.
AudioDeviceEnumerator provides programmatic access to devices
and their unique ids if it is necessary for a client to select
an id at runtime.